@@ -180,102 +180,6 @@ GtkSourceUndoManager	*gtk_source_buffer_get_undo_manager			(GtkSourceBuffer	*buf
 void			 gtk_source_buffer_set_undo_manager			(GtkSourceBuffer	*buffer,
 										 GtkSourceUndoManager	*manager);
 
-void			 gtk_source_buffer_set_search_text			(GtkSourceBuffer	*buffer,
-										 const gchar		*text);
-
-const gchar		*gtk_source_buffer_get_search_text			(GtkSourceBuffer	*buffer);
-
-void			 gtk_source_buffer_set_case_sensitive_search		(GtkSourceBuffer	*buffer,
-										 gboolean		 case_sensitive);
-
-gboolean		 gtk_source_buffer_get_case_sensitive_search		(GtkSourceBuffer	*buffer);
-
-void			 gtk_source_buffer_set_search_at_word_boundaries	(GtkSourceBuffer	*buffer,
-										 gboolean		 at_word_boundaries);
-
-gboolean		 gtk_source_buffer_get_search_at_word_boundaries	(GtkSourceBuffer	*buffer);
-
-void			 gtk_source_buffer_set_search_wrap_around		(GtkSourceBuffer	*buffer,
-										 gboolean		 wrap_around);
-
-gboolean		 gtk_source_buffer_get_search_wrap_around		(GtkSourceBuffer	*buffer);
-
-void			 gtk_source_buffer_set_highlight_search			(GtkSourceBuffer	*buffer,
-										 gboolean		 highlight);
-
-gboolean		 gtk_source_buffer_get_highlight_search			(GtkSourceBuffer	*buffer);
-
-gint			 gtk_source_buffer_get_search_occurrences_count		(GtkSourceBuffer	*buffer);
-
-gint			 gtk_source_buffer_get_search_occurrence_position	(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*match_start,
-										 const GtkTextIter	*match_end);
-
-gboolean		 gtk_source_buffer_forward_search			(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*iter,
-										 GtkTextIter		*match_start,
-										 GtkTextIter		*match_end);
-
-void			 gtk_source_buffer_forward_search_async			(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*iter,
-										 GCancellable		*cancellable,
-										 GAsyncReadyCallback	 callback,
-										 gpointer		 user_data);
-
-gboolean		 gtk_source_buffer_forward_search_finish		(GtkSourceBuffer	*buffer,
-										 GAsyncResult		*result,
-										 GtkTextIter		*match_start,
-										 GtkTextIter		*match_end,
-										 GError		       **error);
-
-gboolean		 gtk_source_buffer_backward_search			(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*iter,
-										 GtkTextIter		*match_start,
-										 GtkTextIter		*match_end);
-
-void			 gtk_source_buffer_backward_search_async		(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*iter,
-										 GCancellable		*cancellable,
-										 GAsyncReadyCallback	 callback,
-										 gpointer		 user_data);
-
-gboolean		 gtk_source_buffer_backward_search_finish		(GtkSourceBuffer	*buffer,
-										 GAsyncResult		*result,
-										 GtkTextIter		*match_start,
-										 GtkTextIter		*match_end,
-										 GError		       **error);
-
-gboolean		 gtk_source_buffer_search_replace			(GtkSourceBuffer	*buffer,
-										 const GtkTextIter	*match_start,
-										 const GtkTextIter	*match_end,
-										 const gchar		*replace,
-										 gint			 replace_length);
-
-guint			 gtk_source_buffer_search_replace_all			(GtkSourceBuffer	*buffer,
-										 const gchar		*replace,
-										 gint			 replace_length);
-
-/* private */
-
-G_GNUC_INTERNAL
-void			 _gtk_source_buffer_update_highlight			(GtkSourceBuffer        *buffer,
-										 const GtkTextIter      *start,
-										 const GtkTextIter      *end,
-										 gboolean                synchronous);
-
-G_GNUC_INTERNAL
-GtkSourceMark		*_gtk_source_buffer_source_mark_next			(GtkSourceBuffer        *buffer,
-										 GtkSourceMark          *mark,
-										 const gchar            *category);
-
-G_GNUC_INTERNAL
-GtkSourceMark		*_gtk_source_buffer_source_mark_prev			(GtkSourceBuffer        *buffer,
-										 GtkSourceMark          *mark,
-										 const gchar            *category);
-
-G_GNUC_INTERNAL
-GtkTextTag		*_gtk_source_buffer_get_bracket_match_tag		(GtkSourceBuffer        *buffer);
-
 G_END_DECLS
 
 #endif /* __GTK_SOURCE_BUFFER_H__ */
