@@ -278,7 +278,12 @@ enum
 
 struct _GtkSourceSearchContextPrivate
 {
+	/* Weak ref to the buffer. The buffer has also a weak ref to the search
+	 * context. A strong ref in either direction would prevent the pointed
+	 * object to be finalized.
+	 */
 	GtkTextBuffer *buffer;
+
 	GtkSourceSearchSettings *settings;
 
 	/* The tag to apply to search occurrences. Even if the highlighting is
@@ -286,6 +291,12 @@ struct _GtkSourceSearchContextPrivate
 	 */
 	GtkTextTag *found_tag;
 
+	/* A reference to the tag table where the found_tag is added. The sole
+	 * purpose is to remove the found_tag in dispose(). We can not rely on
+	 * 'buffer' since it is a weak reference.
+	 */
+	GtkTextTagTable *tag_table;
+
 	/* The region to scan and highlight. If NULL, the scan is finished. */
 	GtkTextRegion *scan_region;
 
@@ -496,7 +507,7 @@ clear_task (GtkSourceSearchContext *search)
 {
 	if (search->priv->task_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->task_region, TRUE);
+		gtk_text_region_destroy (search->priv->task_region);
 		search->priv->task_region = NULL;
 	}
 
@@ -519,13 +530,13 @@ clear_search (GtkSourceSearchContext *search)
 {
 	if (search->priv->scan_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->scan_region, TRUE);
+		gtk_text_region_destroy (search->priv->scan_region);
 		search->priv->scan_region = NULL;
 	}
 
 	if (search->priv->high_priority_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->high_priority_region, TRUE);
+		gtk_text_region_destroy (search->priv->high_priority_region);
 		search->priv->high_priority_region = NULL;
 	}
 
@@ -990,7 +1001,7 @@ smart_forward_search_async_step (GtkSourceSearchContext *search,
 
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		while (basic_forward_search (search, &iter, &match_start, &match_end, &limit))
@@ -1034,7 +1045,7 @@ smart_forward_search_async_step (GtkSourceSearchContext *search,
 
 	if (search->priv->task_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->task_region, TRUE);
+		gtk_text_region_destroy (search->priv->task_region);
 	}
 
 	search->priv->task_region = region;
@@ -1126,7 +1137,7 @@ smart_backward_search_async_step (GtkSourceSearchContext *search,
 
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		while (basic_backward_search (search, &iter, &match_start, &match_end, &limit))
@@ -1170,7 +1181,7 @@ smart_backward_search_async_step (GtkSourceSearchContext *search,
 
 	if (search->priv->task_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->task_region, TRUE);
+		gtk_text_region_destroy (search->priv->task_region);
 	}
 
 	search->priv->task_region = region;
@@ -1274,7 +1285,7 @@ adjust_subregion (GtkSourceSearchContext *search,
 
 			if (region != NULL)
 			{
-				gtk_text_region_destroy (region, TRUE);
+				gtk_text_region_destroy (region);
 			}
 		}
 	}
@@ -1327,7 +1338,7 @@ adjust_subregion (GtkSourceSearchContext *search,
 
 			if (region != NULL)
 			{
-				gtk_text_region_destroy (region, TRUE);
+				gtk_text_region_destroy (region);
 			}
 		}
 	}
@@ -1449,7 +1460,7 @@ remove_occurrences_in_range (GtkSourceSearchContext *search,
 
 			if (region != NULL)
 			{
-				gtk_text_region_destroy (region, TRUE);
+				gtk_text_region_destroy (region);
 			}
 		}
 
@@ -1646,7 +1657,7 @@ resume_task (GtkSourceSearchContext *search)
 
 	if (search->priv->task_region != NULL)
 	{
-		gtk_text_region_destroy (search->priv->task_region, TRUE);
+		gtk_text_region_destroy (search->priv->task_region);
 		search->priv->task_region = NULL;
 	}
 
@@ -1696,7 +1707,7 @@ idle_scan_normal_search (GtkSourceSearchContext *search)
 		 */
 		scan_all_region (search, search->priv->high_priority_region);
 
-		gtk_text_region_destroy (search->priv->high_priority_region, TRUE);
+		gtk_text_region_destroy (search->priv->high_priority_region);
 		search->priv->high_priority_region = NULL;
 
 		return G_SOURCE_CONTINUE;
@@ -1718,7 +1729,7 @@ idle_scan_normal_search (GtkSourceSearchContext *search)
 
 		if (search->priv->scan_region != NULL)
 		{
-			gtk_text_region_destroy (search->priv->scan_region, TRUE);
+			gtk_text_region_destroy (search->priv->scan_region);
 			search->priv->scan_region = NULL;
 		}
 
@@ -1783,7 +1794,7 @@ regex_search_handle_high_priority_region (GtkSourceSearchContext *search)
 		gtk_text_region_iterator_next (&region_iter);
 	}
 
-	gtk_text_region_destroy (region, TRUE);
+	gtk_text_region_destroy (region);
 }
 
 /* Returns TRUE if the segment is finished, and FALSE on partial match. */
@@ -2001,7 +2012,7 @@ idle_scan_regex_search (GtkSourceSearchContext *search)
 	{
 		regex_search_handle_high_priority_region (search);
 
-		gtk_text_region_destroy (search->priv->high_priority_region, TRUE);
+		gtk_text_region_destroy (search->priv->high_priority_region);
 		search->priv->high_priority_region = NULL;
 
 		return G_SOURCE_CONTINUE;
@@ -2031,7 +2042,7 @@ idle_scan_regex_search (GtkSourceSearchContext *search)
 
 		if (search->priv->scan_region != NULL)
 		{
-			gtk_text_region_destroy (search->priv->scan_region, TRUE);
+			gtk_text_region_destroy (search->priv->scan_region);
 			search->priv->scan_region = NULL;
 		}
 
@@ -2092,7 +2103,7 @@ smart_forward_search_step (GtkSourceSearchContext *search,
 	{
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		while (basic_forward_search (search, &iter, match_start, match_end, &limit))
@@ -2121,7 +2132,7 @@ smart_forward_search_step (GtkSourceSearchContext *search,
 		scan_region_forward (search, region);
 	}
 
-	gtk_text_region_destroy (region, TRUE);
+	gtk_text_region_destroy (region);
 
 	return FALSE;
 }
@@ -2191,7 +2202,7 @@ smart_backward_search_step (GtkSourceSearchContext *search,
 	{
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		while (basic_backward_search (search, &iter, match_start, match_end, &limit))
@@ -2220,7 +2231,7 @@ smart_backward_search_step (GtkSourceSearchContext *search,
 		scan_region_forward (search, region);
 	}
 
-	gtk_text_region_destroy (region, TRUE);
+	gtk_text_region_destroy (region);
 
 	return FALSE;
 }
@@ -2473,9 +2484,15 @@ set_buffer (GtkSourceSearchContext *search,
 	    GtkSourceBuffer        *buffer)
 {
 	g_assert (search->priv->buffer == NULL);
+	g_assert (search->priv->tag_table == NULL);
 
 	search->priv->buffer = GTK_TEXT_BUFFER (buffer);
-	g_object_ref (search->priv->buffer);
+
+	g_object_add_weak_pointer (G_OBJECT (buffer),
+				   (gpointer *)&search->priv->buffer);
+
+	search->priv->tag_table = gtk_text_buffer_get_tag_table (search->priv->buffer);
+	g_object_ref (search->priv->tag_table);
 
 	g_signal_connect_object (buffer,
 				 "insert-text",
@@ -2587,16 +2604,24 @@ gtk_source_search_context_dispose (GObject *object)
 
 	clear_search (search);
 
-	if (search->priv->found_tag != NULL)
+	if (search->priv->found_tag != NULL &&
+	    search->priv->tag_table != NULL)
 	{
-		GtkTextTagTable *tag_table = gtk_text_buffer_get_tag_table (search->priv->buffer);
-
-		gtk_text_tag_table_remove (tag_table, search->priv->found_tag);
+		gtk_text_tag_table_remove (search->priv->tag_table,
+					   search->priv->found_tag);
 
 		g_clear_object (&search->priv->found_tag);
+		g_clear_object (&search->priv->tag_table);
+	}
+
+	if (search->priv->buffer != NULL)
+	{
+		g_object_remove_weak_pointer (G_OBJECT (search->priv->buffer),
+					      (gpointer *)&search->priv->buffer);
+
+		search->priv->buffer = NULL;
 	}
 
-	g_clear_object (&search->priv->buffer);
 	g_clear_object (&search->priv->settings);
 
 	G_OBJECT_CLASS (gtk_source_search_context_parent_class)->dispose (object);
@@ -3032,7 +3057,7 @@ gtk_source_search_context_get_occurrence_position (GtkSourceSearchContext *searc
 
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		if (!empty)
@@ -3072,7 +3097,7 @@ gtk_source_search_context_get_occurrence_position (GtkSourceSearchContext *searc
 
 		if (region != NULL)
 		{
-			gtk_text_region_destroy (region, TRUE);
+			gtk_text_region_destroy (region);
 		}
 
 		if (!empty)
@@ -3620,7 +3645,7 @@ _gtk_source_search_context_update_highlight (GtkSourceSearchContext *search,
 	{
 		if (region_to_highlight != NULL)
 		{
-			gtk_text_region_destroy (region_to_highlight, TRUE);
+			gtk_text_region_destroy (region_to_highlight);
 		}
 
 		return;
@@ -3635,7 +3660,7 @@ _gtk_source_search_context_update_highlight (GtkSourceSearchContext *search,
 			 * means that the visible region has changed. So we can
 			 * destroy the old high_priority_region.
 			 */
-			gtk_text_region_destroy (search->priv->high_priority_region, TRUE);
+			gtk_text_region_destroy (search->priv->high_priority_region);
 		}
 
 		search->priv->high_priority_region = region_to_highlight;
@@ -3657,6 +3682,6 @@ _gtk_source_search_context_update_highlight (GtkSourceSearchContext *search,
 	else
 	{
 		scan_all_region (search, region_to_highlight);
-		gtk_text_region_destroy (region_to_highlight, TRUE);
+		gtk_text_region_destroy (region_to_highlight);
 	}
 }
